@@ -47,13 +47,20 @@ signature_to_string (GgitSignature *signature)
 
 static int
 diff_print_cb (GgitDiffDelta    *delta,
-               GgitDiffRange    *range,
-               GgitDiffLineType  line_type,
-               const gchar      *content,
-               gsize             content_len,
+               GgitDiffHunk     *hunk,
+               GgitDiffLine     *line,
                gpointer          user_data)
 {
-	g_print ("%s", content);
+	const guint8 *content;
+	gsize len;
+	gchar *s;
+
+	content = ggit_diff_line_get_content (line, &len);
+	s = g_strndup (content, len);
+
+	g_print ("%s", s);
+	g_free (s);
+
 	return 0;
 }
 
@@ -163,19 +170,19 @@ main (int   argc,
 			GgitCommit *parent_commit;
 			GgitTree *commit_tree;
 			GgitTree *parent_tree;
-			GgitDiffList *diff;
+			GgitDiff *diff;
 
 			parent_commit = ggit_commit_parents_get (commit_parents, 0);
 			commit_tree = ggit_commit_get_tree (commit);
 			parent_tree = ggit_commit_get_tree (parent_commit);
 
-			diff = ggit_diff_list_new_tree_to_tree (repo,
-			                                        parent_tree,
-			                                        commit_tree,
-			                                        NULL, &err);
+			diff = ggit_diff_new_tree_to_tree (repo,
+			                                   parent_tree,
+			                                   commit_tree,
+			                                   NULL, &err);
 			g_assert_no_error (err);
 
-			ggit_diff_list_print_patch (diff, diff_print_cb, NULL, &err);
+			ggit_diff_print (diff, GGIT_DIFF_FORMAT_PATCH, diff_print_cb, NULL, &err);
 			g_assert_no_error (err);
 
 			g_object_unref (diff);
