@@ -52,6 +52,29 @@ ggit_cap_flags_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_blame_flags_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GFlagsValue values[] = {
+			{ GGIT_BLAME_NORMAL,
+			  "GGIT_BLAME_NORMAL",
+			  "normal" },
+			{ GGIT_BLAME_TRACK_COPIES_SAME_FILE,
+			  "GGIT_BLAME_TRACK_COPIES_SAME_FILE",
+			  "track-copies-same-file" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_flags_register_static (
+				g_intern_static_string ("GgitBlameFlags"),
+				values);
+	}
+	return the_type;
+}
+
 GType
 ggit_config_level_get_type (void)
 {
@@ -904,6 +927,35 @@ ggit_status_show_get_type (void)
 	return the_type;
 }
 
+GType
+ggit_attribute_check_flags_get_type (void)
+{
+	static GType the_type = 0;
+	
+	if (the_type == 0)
+	{
+		static const GFlagsValue values[] = {
+			{ GGIT_ATTRIBUTE_CHECK_FILE_THEN_INDEX,
+			  "GGIT_ATTRIBUTE_CHECK_FILE_THEN_INDEX",
+			  "file-then-index" },
+			{ GGIT_ATTRIBUTE_CHECK_INDEX_THEN_FILE,
+			  "GGIT_ATTRIBUTE_CHECK_INDEX_THEN_FILE",
+			  "index-then-file" },
+			{ GGIT_ATTRIBUTE_CHECK_INDEX_ONLY,
+			  "GGIT_ATTRIBUTE_CHECK_INDEX_ONLY",
+			  "index-only" },
+			{ GGIT_ATTRIBUTE_CHECK_NO_SYSTEM,
+			  "GGIT_ATTRIBUTE_CHECK_NO_SYSTEM",
+			  "no-system" },
+			{ 0, NULL, NULL }
+		};
+		the_type = g_flags_register_static (
+				g_intern_static_string ("GgitAttributeCheckFlags"),
+				values);
+	}
+	return the_type;
+}
+
 
 /* Generated data ends here */
 
