@@ -20,6 +20,8 @@
 
 #include "ggit-index-entry.h"
 #include "ggit-index.h"
+#include "ggit-repository.h"
+
 #include <string.h>
 
 struct _GgitIndexEntries
@@ -219,31 +221,49 @@ ggit_index_entries_get_by_index (GgitIndexEntries *entries,
  * Get a #GgitIndexEntry by index. Note that the returned #GgitIndexEntry is
  * _only_ valid as long as:
  *
- * 1) The associated index has been closed
+ * 1) The associated index has not been closed
  * 2) The entry has not been removed (see ggit_index_remove())
  * 3) The index has not been refreshed (see ggit_index_read())
  *
  * Changes to the #GgitIndexEntry will be reflected in the index once written
  * back to disk using ggit_index_write().
  *
+ * @stage indicates the stage to search the file for. Stages are used in the
+ * index when merge conflicts occur, such that multiple versions of the same
+ * file can be represented in the index. Stage 0 is associated with the working
+ * tree, while stages 1 to 3 are associated with the various versions of the
+ * file in a merge conflict. The special value -1 can be used to match the first
+ * file encountered in any stage.
+ *
  * Returns: (transfer full): a #GgitIndexEntry or %NULL if it was not found.
  *
  **/
 GgitIndexEntry *
 ggit_index_entries_get_by_path (GgitIndexEntries *entries,
                                 GFile            *file,
-                                gboolean          stage)
+                                gint              stage)
 {
 	git_index *gidx;
 	const git_index_entry *entry;
 	gchar *path;
+	GgitRepository *repo;
+	GFile *wd;
 
 	g_return_val_if_fail (entries != NULL, NULL);
 	g_return_val_if_fail (G_IS_FILE (file), NULL);
 	g_return_val_if_fail (stage >= 0 && stage <= 3, NULL);
 
+	repo = ggit_index_get_owner (entries->owner);
+
+	wd = ggit_repository_get_workdir (repo);
+	path = g_file_get_relative_path (wd, file);
+
+	g_object_unref (wd);
+	g_object_unref (repo);
+
+	g_return_val_if_fail (path != NULL, NULL);
+
 	gidx = _ggit_index_get_index (entries->owner);
-	path = g_file_get_path (file);
 	entry = git_index_get_bypath (gidx, path, stage);
 	g_free (path);
 
