@@ -34,6 +34,8 @@
 #include "ggit-status-options.h"
 #include "ggit-tree-builder.h"
 #include "ggit-branch-enumerator.h"
+#include "ggit-blame.h"
+#include "ggit-blame-options.h"
 
 #define GGIT_REPOSITORY_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE((object), GGIT_TYPE_REPOSITORY, GgitRepositoryPrivate))
 
@@ -2348,4 +2350,91 @@ ggit_repository_create_index_entry_for_path (GgitRepository  *repository,
 	return ret;
 }
 
+/**
+ * ggit_repository_blame_file:
+ * @repository: a #GgitRepository.
+ * @file: the file to blame.
+ * @blame_options: (allow-none): blame options.
+ * @error: a #GError.
+ *
+ * Get a blame for a single file.
+ *
+ * Returns: (transfer full): a #GgitBlame.
+ *
+ **/
+GgitBlame *
+ggit_repository_blame_file (GgitRepository    *repository,
+                            GFile             *file,
+                            GgitBlameOptions  *blame_options,
+                            GError           **error)
+{
+	git_blame *blame;
+	gchar *path;
+	int ret;
+
+	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
+	g_return_val_if_fail (G_IS_FILE (file), NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	path = g_file_get_relative_path (repository->priv->workdir, file);
+
+	ret = git_blame_file (&blame,
+	                      _ggit_native_get (repository),
+	                      path,
+	                      _ggit_blame_options_get_blame_options (blame_options));
+
+	g_free (path);
+
+	if (ret != GIT_OK)
+	{
+		_ggit_error_set (error, ret);
+		return NULL;
+	}
+
+	return _ggit_blame_wrap (blame);
+}
+
+/**
+ * ggit_repository_get_attribute:
+ * @repository: a #GgitRepository.
+ * @path: the relative path to the file.
+ * @name: the name of the attribute.
+ * @flags: a #GgitAttributeCheckFlags.
+ * @error: a #GError.
+ *
+ * Get the attribute value of the specified attribute for the given file.
+ *
+ * Returns: the attribute value, or %NULL.
+ *
+ **/
+const gchar *
+ggit_repository_get_attribute (GgitRepository           *repository,
+                               const gchar              *path,
+                               const gchar              *name,
+                               GgitAttributeCheckFlags   flags,
+                               GError                  **error)
+{
+	const char *value;
+	int ret;
+
+	g_return_val_if_fail (GGIT_IS_REPOSITORY (repository), NULL);
+	g_return_val_if_fail (path != NULL, NULL);
+	g_return_val_if_fail (name != NULL, NULL);
+	g_return_val_if_fail (error == NULL || *error == NULL, NULL);
+
+	ret = git_attr_get (&value,
+	                    _ggit_native_get (repository),
+	                    flags,
+	                    path,
+	                    name);
+
+	if (ret != GIT_OK)
+	{
+		_ggit_error_set (error, ret);
+		return NULL;
+	}
+
+	return value;
+}
+
 /* ex:set ts=8 noet: */
