@@ -206,4 +206,12 @@ ASSERT_ENUM (GGIT_STATUS_SHOW_INDEX_AND_WORKDIR, GIT_STATUS_SHOW_INDEX_AND_WORKD
 ASSERT_ENUM (GGIT_STATUS_SHOW_INDEX_ONLY,        GIT_STATUS_SHOW_INDEX_ONLY);
 ASSERT_ENUM (GGIT_STATUS_SHOW_WORKDIR_ONLY,      GIT_STATUS_SHOW_WORKDIR_ONLY);
 
+ASSERT_ENUM (GGIT_BLAME_NORMAL,                 GIT_BLAME_NORMAL);
+ASSERT_ENUM (GGIT_BLAME_TRACK_COPIES_SAME_FILE, GIT_BLAME_TRACK_COPIES_SAME_FILE);
+
+ASSERT_ENUM (GGIT_ATTRIBUTE_CHECK_FILE_THEN_INDEX, GIT_ATTR_CHECK_FILE_THEN_INDEX);
+ASSERT_ENUM (GGIT_ATTRIBUTE_CHECK_INDEX_THEN_FILE, GIT_ATTR_CHECK_INDEX_THEN_FILE);
+ASSERT_ENUM (GGIT_ATTRIBUTE_CHECK_INDEX_ONLY,      GIT_ATTR_CHECK_INDEX_ONLY);
+ASSERT_ENUM (GGIT_ATTRIBUTE_CHECK_NO_SYSTEM,       GIT_ATTR_CHECK_NO_SYSTEM);
+
 /* ex:set ts=8 noet: */
